@@ -1,15 +1,15 @@
 #'
-#' Run NGLVieweR example Shiny app
+#'Run NGLVieweR example Shiny app
 #'
-#' @description
-#' Launch an example to demonstrate how to use \code{NGLvieweR} in Shiny.
+#'@description Launch an example to demonstrate how to use \code{NGLvieweR} in
+#'Shiny.
 #'
-#' @param example Example type for which to see an example, possible values are:
-#' "basic", "API", "addSelection", "removeSelection", "snapshot",
-#' "updateAnimation", "updateColor", "updateFocus", "updateFullscreen",
-#' "updateRepresentation", "updateSelection", "updateStage", "updateVisibility" and
-#' "updateZoomMove".
-#' @return Call to load Shiny example.
+#'@param example Example type for which to see an example, possible values are:
+#'  "basic", "API", "addSelection", "removeSelection", "snapshot",
+#'  "updateAnimation", "updateColor", "updateFocus", "updateFullscreen",
+#'  "updateRepresentation", "updateSelection", "updateStage", "updateVisibility",
+#'  "updateZoomMove", "multiStructureSelection".
+#'@return Call to load Shiny example.
 #' @examples
 #'
 #' if (interactive()) {
@@ -34,7 +34,7 @@ example <- match.arg(
     "basic", "API", "addSelection", "removeSelection", "snapshot",
     "updateAnimation", "updateColor", "updateFocus", "updateFullscreen",
     "updateRepresentation", "updateSelection", "updateStage", "updateVisibility",
-    "updateZoomMove"
+    "updateZoomMove", "multiStructureSelection"
   ),
   several.ok = FALSE
 )
