@@ -1,12 +1,20 @@
 #'Add a selection
 #'
-#'@description
-#'Add a new selection to a NGLVieweR object in Shinymode.
+#'@description Add a new selection to a NGLVieweR object in Shinymode.
 #'@param NGLVieweR_proxy A NGLVieweR object.
-#'@param type Type of representation. Most common options are "cartoon", "ball+stick", "surface", "ribbon" and "label".
-#'@param param Options for the different types of representations. Most common options are \code{name}, \code{opacity}, \code{colorScheme}, \code{sele}, \code{colorValue} and \code{visibility}.
-#'For a full list of options, see the general "RepresentationParameters" method and type specific Label-, Structure- and Surface- RepresentationParameters in the official \href{http://nglviewer.org/ngl/api/}{NGL.js} manual.
-#'@return API call containing \code{NGLVieweR} \code{id} and list of message parameters.
+#'@param type Type of representation. Most common options are "cartoon",
+#'  "ball+stick", "surface", "ribbon" and "label".
+#'@param param Options for the different types of representations. Most common
+#'  options are \code{name}, \code{opacity}, \code{colorScheme}, \code{sele},
+#'  \code{colorValue} and \code{visibility}. For a full list of options, see the
+#'  general "RepresentationParameters" method and type specific Label-,
+#'  Structure- and Surface- RepresentationParameters in the official
+#'  \href{http://nglviewer.org/ngl/api/}{NGL.js} manual.
+#'@param structureIndex (optional) The index of the specific structure to which
+#'  the selection should be added (index 0 for the first). If not specified, the
+#'  selection will be applied to all loaded structures.
+#'@return API call containing \code{NGLVieweR} \code{id} and list of message
+#'  parameters.
 #'@family selections
 #'@seealso
 #'* [updateRepresentation()] Update an existing NGLVieweR representation.
@@ -20,10 +28,10 @@
 #'                                          colorScheme="element"
 #'                                          ))
 #' }
-#' 
+#'
 #' if (interactive()) {
 #' library(shiny)
-#' 
+#'
 #' ui <- fluidPage(
 #'   titlePanel("Viewer with API inputs"),
 #'   sidebarLayout(
@@ -57,7 +65,7 @@
 #'           )
 #'       )
 #'   })
-#' 
+#'
 #'   observeEvent(input$remove, {
 #'     NGLVieweR_proxy("structure") %>%
 #'       removeSelection("sel1")
@@ -66,21 +74,25 @@
 #' shinyApp(ui, server)
 #' }
 #'@export
-addSelection <- function(NGLVieweR_proxy, type, param = list()) {
-
+addSelection <- function(NGLVieweR_proxy, type, param = list(), structureIndex = NULL) {
+  
+  if (!is.null(structureIndex)) {
+    param$structureIndex <- structureIndex
+  }
+  
   message <- list(id = NGLVieweR_proxy$id, type = type, param = param)
   NGLVieweR_proxy$session$sendCustomMessage("NGLVieweR:addSelection", message)
-
+  
   return(NGLVieweR_proxy)
 }
 
 #'Remove a selection
 #'
-#'@description
-#'Remove an existing NGLVieweR selection in Shinymode.
+#'@description Remove an existing NGLVieweR selection in Shinymode.
 #'@param NGLVieweR_proxy A NGLVieweR object.
 #'@param name Name of selection to be removed.
-#'@return API call containing \code{NGLVieweR} \code{id} and list of message parameters.
+#'@return API call containing \code{NGLVieweR} \code{id} and list of message
+#'  parameters.
 #'@family selections
 #'@seealso
 #'* [NGLVieweR_example()] See example "removeSelection".
@@ -89,10 +101,10 @@ addSelection <- function(NGLVieweR_proxy, type, param = list()) {
 #' NGLVieweR_proxy("structure") %>%
 #'      removeSelection("sel1")
 #' }
-#' 
+#'
 #' if (interactive()) {
 #'   library(shiny)
-#' 
+#'
 #'   ui <- fluidPage(
 #'     titlePanel("Viewer with API inputs"),
 #'     sidebarLayout(
@@ -126,7 +138,7 @@ addSelection <- function(NGLVieweR_proxy, type, param = list()) {
 #'             )
 #'         )
 #'     })
-#' 
+#'
 #'     observeEvent(input$remove, {
 #'       NGLVieweR_proxy("structure") %>%
 #'         removeSelection("sel1")
@@ -134,7 +146,7 @@ addSelection <- function(NGLVieweR_proxy, type, param = list()) {
 #'   }
 #'   shinyApp(ui, server)
 #' }
-#' @export
+#'@export
 removeSelection <- function(NGLVieweR_proxy, name) {
 
   message <- list(id = NGLVieweR_proxy$id, name = name)
@@ -145,13 +157,14 @@ removeSelection <- function(NGLVieweR_proxy, name) {
 
 #'Update a selection
 #'
-#'@description
-#'Update the selected residues of an existing NGLVieweR selection in
+#'@description Update the selected residues of an existing NGLVieweR selection
+#'in
 #'@param NGLVieweR_proxy A NGLVieweR object.
 #'@param name Name of selection.
-#'@param sele Selected atoms/residues.
-#'See the section "selection-language" in the official \href{http://nglviewer.org/ngl/api/}{NGL.js} manual.
-#'@return API call containing \code{NGLVieweR} \code{id} and list of message parameters.
+#'@param sele Selected atoms/residues. See the section "selection-language" in
+#'  the official \href{http://nglviewer.org/ngl/api/}{NGL.js} manual.
+#'@return API call containing \code{NGLVieweR} \code{id} and list of message
+#'  parameters.
 #'@family selections
 #'@seealso
 #'* [NGLVieweR_example()] See example "updateSelection".
@@ -160,7 +173,7 @@ removeSelection <- function(NGLVieweR_proxy, name) {
 #' NGLVieweR_proxy("structure") %>%
 #'   updateSelection("ball+stick", sele = "1-20")
 #' }
-#' 
+#'
 #' if (interactive()) {
 #'   library(shiny)
 #'   ui <- fluidPage(
@@ -209,13 +222,15 @@ updateSelection <- function(NGLVieweR_proxy, name = name, sele = "none"){
 
 #'Update color of a selection
 #'
-#'@description
-#'Update color of an existing NGLVieweR selection in Shinymode.
+#'@description Update color of an existing NGLVieweR selection in Shinymode.
 #'@param NGLVieweR_proxy A NGLVieweR object.
 #'@param name Name of selection to alter the color.
-#'@param color Can be a colorValue (color name or HEX code) or colorScheme (e.g. "element", "resname", "random" or "residueindex").
-#'For a full list of options, see the "Colormaker" section in the official \href{http://nglviewer.org/ngl/api/}{NGL.js} manual.
-#'@return API call containing \code{NGLVieweR} \code{id} and list of message parameters.
+#'@param color Can be a colorValue (color name or HEX code) or colorScheme (e.g.
+#'  "element", "resname", "random" or "residueindex"). For a full list of
+#'  options, see the "Colormaker" section in the official
+#'  \href{http://nglviewer.org/ngl/api/}{NGL.js} manual.
+#'@return API call containing \code{NGLVieweR} \code{id} and list of message
+#'  parameters.
 #'@family updates
 #'@seealso
 #'* [NGLVieweR_example()] See example "updateColor".
@@ -227,7 +242,8 @@ updateSelection <- function(NGLVieweR_proxy, name = name, sele = "none"){
 #'
 #' if (interactive()) {
 #'   library(shiny)
-#' 
+#'   library(colourpicker)
+#'
 #'   ui <- fluidPage(
 #'     titlePanel("Viewer with API inputs"),
 #'     sidebarLayout(
@@ -254,7 +270,7 @@ updateSelection <- function(NGLVieweR_proxy, name = name, sele = "none"){
 #'   }
 #'   shinyApp(ui, server)
 #' }
-#' @export
+#'@export
 updateColor <- function(NGLVieweR_proxy, name, color) {
 
   message <- list(id = NGLVieweR_proxy$id, name = name, color = color)
@@ -265,16 +281,17 @@ updateColor <- function(NGLVieweR_proxy, name, color) {
 
 #'Snapshot
 #'
-#'@description
-#'Make a snapshot of a NGLVieweR object in Shinymode.
+#'@description Make a snapshot of a NGLVieweR object in Shinymode.
 #'@param NGLVieweR_proxy A NGLVieweR object.
 #'@param fileName Optional name for Snapshot (default = "Snapshot").
-#'@param param Of type list, can be; antialias \code{TRUE/FALSE}, trim \code{TRUE/FALSE}, transparent \code{TRUE/FALSE} or scale \code{numeric}.
-#'For a full list of options, see "makeImage" and "ImageParameters" in the official \href{http://nglviewer.org/ngl/api/}{NGL.js} manual.
-#'@return API call containing \code{NGLVieweR} \code{id} and list of message parameters.
+#'@param param Of type list, can be; antialias \code{TRUE/FALSE}, trim
+#'  \code{TRUE/FALSE}, transparent \code{TRUE/FALSE} or scale \code{numeric}.
+#'  For a full list of options, see "makeImage" and "ImageParameters" in the
+#'  official \href{http://nglviewer.org/ngl/api/}{NGL.js} manual.
+#'@return API call containing \code{NGLVieweR} \code{id} and list of message
+#'  parameters.
 #'@family options
-#'@seealso
-#'[NGLVieweR_example()] See example "snapshot".
+#'@seealso [NGLVieweR_example()] See example "snapshot".
 #'@examples
 #'\dontrun{
 #'NGLVieweR_proxy("structure") %>%
@@ -287,7 +304,7 @@ updateColor <- function(NGLVieweR_proxy, name, color) {
 #'
 #' if (interactive()) {
 #'   library(shiny)
-#' 
+#'
 #'   ui <- fluidPage(
 #'     titlePanel("Viewer with API inputs"),
 #'     sidebarLayout(
@@ -335,25 +352,25 @@ snapShot <- function(NGLVieweR_proxy, fileName = "Snapshot", param = list()) {
 
 #'Update visibility
 #'
-#'@description
-#'Hide or show an existing NGLVieweR selection in Shinymode.
+#'@description Hide or show an existing NGLVieweR selection in Shinymode.
 #'@param NGLVieweR_proxy A NGLVieweR object.
 #'@param name Name of selection to alter the color.
-#'@param value Hide \code{FALSE} or show \code{TRUE} selection.
-#'For a full description see "setVisibility" in the official \href{http://nglviewer.org/ngl/api/}{NGL.js} manual.
-#'@return API call containing \code{NGLVieweR} \code{id} and list of message parameters.
+#'@param value Hide \code{FALSE} or show \code{TRUE} selection. For a full
+#'  description see "setVisibility" in the official
+#'  \href{http://nglviewer.org/ngl/api/}{NGL.js} manual.
+#'@return API call containing \code{NGLVieweR} \code{id} and list of message
+#'  parameters.
 #'@family updates
-#'@seealso
-#'[NGLVieweR_example()] See example "updateVisibility".
+#'@seealso [NGLVieweR_example()] See example "updateVisibility".
 #'@examples
 #'\dontrun{
 #' NGLVieweR_proxy("structure") %>%
 #'  updateVisibility("cartoon", value = TRUE)
 #' }
-#' 
+#'
 #' if (interactive()) {
 #' library(shiny)
-#' 
+#'
 #' ui = fluidPage(
 #'   titlePanel("Viewer with API inputs"),
 #'   sidebarLayout(
@@ -369,18 +386,18 @@ snapShot <- function(NGLVieweR_proxy, fileName = "Snapshot", param = list()) {
 #' server = function(input, output) {
 #'   output$structure <- renderNGLVieweR({
 #'     NGLVieweR("7CID") %>%
-#'       addRepresentation("cartoon", 
+#'       addRepresentation("cartoon",
 #'                         param = list(name = "cartoon", color="residueindex"))
 #'   })
 #'   observeEvent(input$show, {
 #'     NGLVieweR_proxy("structure") %>%
 #'       updateVisibility("cartoon", value = TRUE)
-#' 
+#'
 #'   })
 #'   observeEvent(input$hide, {
 #'     NGLVieweR_proxy("structure") %>%
 #'       updateVisibility("cartoon", value = FALSE)
-#' 
+#'
 #'   })
 #' }
 #' shinyApp(ui, server)
@@ -396,13 +413,17 @@ updateVisibility <- function(NGLVieweR_proxy, name, value = FALSE) {
 
 #'Update Representation
 #'
-#'@description
-#'Update an existing NGLVieweR representation in Shinymode.
+#'@description Update an existing NGLVieweR representation in Shinymode.
 #'@param NGLVieweR_proxy A NGLVieweR object.
 #'@param name Name of representation to alter the color.
-#'@param param Options for the different types of representations. Most common options are \code{name}, \code{opacity}, \code{colorScheme}, \code{colorValue} and \code{visibility}.
-#'For a full list of options, see the general "RepresentationParameters" method and type specific Label-, Structure- and Surface- RepresentationParameters in the official \href{http://nglviewer.org/ngl/api/}{NGL.js} manual.
-#'@return API call containing \code{NGLVieweR} \code{id} and list of message parameters.
+#'@param param Options for the different types of representations. Most common
+#'  options are \code{name}, \code{opacity}, \code{colorScheme},
+#'  \code{colorValue} and \code{visibility}. For a full list of options, see the
+#'  general "RepresentationParameters" method and type specific Label-,
+#'  Structure- and Surface- RepresentationParameters in the official
+#'  \href{http://nglviewer.org/ngl/api/}{NGL.js} manual.
+#'@return API call containing \code{NGLVieweR} \code{id} and list of message
+#'  parameters.
 #'@family updates
 #'@seealso
 #'* [addSelection()] Add a new selection to a NGLVieweR object.
@@ -419,10 +440,10 @@ updateVisibility <- function(NGLVieweR_proxy, name, value = FALSE) {
 #'     )
 #'   )
 #' }
-#' 
+#'
 #' if (interactive()) {
 #' library(shiny)
-#' 
+#'
 #' ui = fluidPage(
 #'   titlePanel("Viewer with API inputs"),
 #'   sidebarLayout(
@@ -439,7 +460,7 @@ updateVisibility <- function(NGLVieweR_proxy, name, value = FALSE) {
 #' server = function(input, output) {
 #'   output$structure <- renderNGLVieweR({
 #'     NGLVieweR("7CID") %>%
-#'       addRepresentation("cartoon", 
+#'       addRepresentation("cartoon",
 #'                         param = list(name = "cartoon", color="red"))
 #'   })
 #' observeEvent(input$update, {
@@ -454,7 +475,7 @@ updateVisibility <- function(NGLVieweR_proxy, name, value = FALSE) {
 #'  }
 #' shinyApp(ui, server)
 #' }
-#' @export
+#'@export
 updateRepresentation <- function(NGLVieweR_proxy, name, param = list()) {
 
   message <- list(id = NGLVieweR_proxy$id, name = name, param = param)
@@ -465,12 +486,14 @@ updateRepresentation <- function(NGLVieweR_proxy, name, param = list()) {
 
 #'Update Stage
 #'
-#'@description
-#'Update an existing NGLVieweR stage in Shinymode.
+#'@description Update an existing NGLVieweR stage in Shinymode.
 #'@param NGLVieweR_proxy A NGLVieweR object.
-#'@param param Of type list. Most common options are \code{backgroundColor}, \code{rotateSpeed}, \code{zoomSpeed},
-#'\code{hoverTimeout} and \code{lightIntensity}. For a full list of options, see the "StageParameters" method in the official \href{http://nglviewer.org/ngl/api/}{NGL.js} manual.
-#'@return API call containing \code{NGLVieweR} \code{id} and list of message parameters.
+#'@param param Of type list. Most common options are \code{backgroundColor},
+#'  \code{rotateSpeed}, \code{zoomSpeed}, \code{hoverTimeout} and
+#'  \code{lightIntensity}. For a full list of options, see the "StageParameters"
+#'  method in the official \href{http://nglviewer.org/ngl/api/}{NGL.js} manual.
+#'@return API call containing \code{NGLVieweR} \code{id} and list of message
+#'  parameters.
 #'@family updates
 #'@seealso
 #'* [stageParameters()]
@@ -478,14 +501,14 @@ updateRepresentation <- function(NGLVieweR_proxy, name, param = list()) {
 #'@examples
 #'\dontrun{
 #' NGLVieweR("7CID") %>%
-#'  addRepresentation("cartoon", 
+#'  addRepresentation("cartoon",
 #'                    param = list(name = "cartoon", color="red")) %>%
 #'  stageParameters(backgroundColor = "black")
 #' }
-#' 
+#'
 #' if (interactive()) {
 #' library(shiny)
-#' 
+#'
 #' ui = fluidPage(
 #'   titlePanel("Viewer with API inputs"),
 #'   sidebarLayout(
@@ -525,11 +548,11 @@ updateStage <- function(NGLVieweR_proxy, param = list()) {
 
 #'Update Focus
 #'
-#'@description
-#'Update the focus of an existing NGLVieweR object in Shinymode.
+#'@description Update the focus of an existing NGLVieweR object in Shinymode.
 #'@param NGLVieweR_proxy A NGLVieweR object.
 #'@param focus Numeric value between 0-100 (default = 0).
-#'@return API call containing \code{NGLVieweR} \code{id} and list of message parameters.
+#'@return API call containing \code{NGLVieweR} \code{id} and list of message
+#'  parameters.
 #'@family options
 #'@seealso
 #'* [setFocus()]
@@ -556,7 +579,7 @@ updateStage <- function(NGLVieweR_proxy, param = list()) {
 #'   server = function(input, output) {
 #'     output$structure <- renderNGLVieweR({
 #'       NGLVieweR("7CID") %>%
-#'         addRepresentation("cartoon", 
+#'         addRepresentation("cartoon",
 #'         param = list(name = "cartoon", color= "red"))
 #'     })
 #'     observeEvent(input$focus, {
@@ -578,11 +601,12 @@ updateFocus <- function(NGLVieweR_proxy, focus = 0){
 
 #'Update Rock
 #'
-#'@description
-#'Start rock animation and stop spinning. Works on an existing NGLVieweR object in Shinymode.
+#'@description Start rock animation and stop spinning. Works on an existing
+#'NGLVieweR object in Shinymode.
 #'@param NGLVieweR_proxy A NGLVieweR object.
 #'@param rock  If \code{TRUE} (default), start rocking and stop spinning.
-#'@return API call containing \code{NGLVieweR} \code{id} and list of message parameters.
+#'@return API call containing \code{NGLVieweR} \code{id} and list of message
+#'  parameters.
 #'@family animations
 #'@seealso
 #'* [setRock()]
@@ -610,27 +634,27 @@ updateFocus <- function(NGLVieweR_proxy, focus = 0){
 #' server = function(input, output) {
 #'   output$structure <- renderNGLVieweR({
 #'     NGLVieweR("7CID") %>%
-#'       addRepresentation("cartoon", 
+#'       addRepresentation("cartoon",
 #'       param = list(name = "cartoon", color="red"))
 #'   })
 #'
 #'   observeEvent(input$animate,{
 #'     if(input$animate == "Rock"){
-#'       NGLVieweR_proxy("structure") %>% 
+#'       NGLVieweR_proxy("structure") %>%
 #'       updateRock(TRUE)
 #'     } else if(input$animate == "Spin") {
-#'       NGLVieweR_proxy("structure") %>% 
+#'       NGLVieweR_proxy("structure") %>%
 #'       updateSpin(TRUE)
 #'     } else{
-#'       NGLVieweR_proxy("structure") %>% 
-#'       updateRock(FALSE) %>% 
+#'       NGLVieweR_proxy("structure") %>%
+#'       updateRock(FALSE) %>%
 #'       updateSpin(FALSE)
 #'     }
 #'   })
 #'  }
 #' shinyApp(ui, server)
 #'}
-#' @export
+#'@export
 updateRock <- function(NGLVieweR_proxy, rock = TRUE){
 
   message <- list(id = NGLVieweR_proxy$id, rock = rock)
@@ -641,11 +665,12 @@ updateRock <- function(NGLVieweR_proxy, rock = TRUE){
 
 #'Update Spin
 #'
-#'@description
-#'Start spin animation and stop rocking. Works on an existing NGLVieweR object in Shinymode.
+#'@description Start spin animation and stop rocking. Works on an existing
+#'NGLVieweR object in Shinymode.
 #'@param NGLVieweR_proxy A NGLVieweR object.
 #'@param spin  If \code{TRUE} (default), start spinning and stop rocking.
-#'@return API call containing \code{NGLVieweR} \code{id} and list of message parameters.
+#'@return API call containing \code{NGLVieweR} \code{id} and list of message
+#'  parameters.
 #'@family animations
 #'@seealso
 #'* [setSpin()]
@@ -672,7 +697,7 @@ updateRock <- function(NGLVieweR_proxy, rock = TRUE){
 #' server = function(input, output) {
 #'   output$structure <- renderNGLVieweR({
 #'     NGLVieweR("7CID") %>%
-#'       addRepresentation("cartoon", 
+#'       addRepresentation("cartoon",
 #'       param = list(name = "cartoon", color="red"))
 #'   })
 #'
@@ -692,7 +717,7 @@ updateRock <- function(NGLVieweR_proxy, rock = TRUE){
 #'  }
 #' shinyApp(ui, server)
 #'}
-#' @export
+#'@export
 updateSpin <- function(NGLVieweR_proxy, spin = TRUE){
 
   message <- list(id = NGLVieweR_proxy$id, spin = spin)
@@ -703,22 +728,21 @@ updateSpin <- function(NGLVieweR_proxy, spin = TRUE){
 
 #'Fullscreen
 #'
-#'@description
-#'Put viewer in fullscreen. Works in Shinymode.
+#'@description Put viewer in fullscreen. Works in Shinymode.
 #'@param NGLVieweR_proxy A NGLVieweR object.
 #'@param fullscreen If \code{TRUE} put viewer in fullscreen.
-#'@return API call containing \code{NGLVieweR} \code{id} and list of message parameters.
+#'@return API call containing \code{NGLVieweR} \code{id} and list of message
+#'  parameters.
 #'@family options
-#'@seealso
-#'[NGLVieweR_example()] See example "updateFullscreen".
+#'@seealso [NGLVieweR_example()] See example "updateFullscreen".
 #'@examples
 #'\dontrun{
 #' NGLVieweR_proxy("structure") %>% updateFullscreen()
 #' }
-#' 
+#'
 #' if (interactive()) {
 #' library(shiny)
-#' 
+#'
 #' ui <- fluidPage(
 #'   titlePanel("Viewer with API inputs"),
 #'   sidebarLayout(
@@ -737,7 +761,7 @@ updateSpin <- function(NGLVieweR_proxy, spin = TRUE){
 #'       param = list(name = "cartoon", color = "red")
 #'     )
 #' })
-#' 
+#'
 #'   observeEvent(input$fullscreen, {
 #'   NGLVieweR_proxy("structure") %>%
 #'     updateFullscreen()
@@ -757,16 +781,20 @@ updateFullscreen <- function(NGLVieweR_proxy, fullscreen = TRUE){
 
 #'Update zoomMove
 #'
-#'@description
-#'Add a zoom animation on an existing NGLVieweR object.
+#'@description Add a zoom animation on an existing NGLVieweR object.
 #'@param NGLVieweR_proxy A NGLVieweR object.
-#'@param center Target distance of selected atoms/residues.
-#'See the section "selection-language" in the official \href{http://nglviewer.org/ngl/api/}{NGL.js} manual.
-#'@param zoom Target zoom of selected atoms/residues.
-#'See the section "selection-language" in the official \href{http://nglviewer.org/ngl/api/}{NGL.js} manual.
+#'@param center Target distance of selected atoms/residues. See the section
+#'  "selection-language" in the official
+#'  \href{http://nglviewer.org/ngl/api/}{NGL.js} manual.
+#'@param zoom Target zoom of selected atoms/residues. See the section
+#'  "selection-language" in the official
+#'  \href{http://nglviewer.org/ngl/api/}{NGL.js} manual.
 #'@param duration Optional animation time in milliseconds (default = 0).
 #'@param z_offSet Optional zoom offset value (default = 0).
-#'@return API call containing \code{NGLVieweR} \code{id} and list of message parameters.
+#'@param structureIndex Optional index of the structure to target for the zoom
+#'  animation. If `NULL` (default), the first structure (index 0) is targeted.
+#'@return API call containing \code{NGLVieweR} \code{id} and list of message
+#'  parameters.
 #'@family animations
 #'@seealso
 #'* [zoomMove()]
@@ -778,10 +806,10 @@ updateFullscreen <- function(NGLVieweR_proxy, fullscreen = TRUE){
 #'                                                z_offSet = 80,
 #'                                                duration = 2000)
 #' }
-#' 
+#'
 #' if (interactive()) {
 #' library(shiny)
-#' 
+#'
 #' ui = fluidPage(
 #'   titlePanel("Viewer with API inputs"),
 #'   sidebarLayout(
@@ -806,7 +834,7 @@ updateFullscreen <- function(NGLVieweR_proxy, fullscreen = TRUE){
 #'       addRepresentation("ball+stick",
 #'       param = list(name = "ball+stick", sele="200"))
 #'   })
-#' 
+#'
 #' observeEvent(input$zoom, {
 #'   NGLVieweR_proxy("structure") %>%
 #'     updateZoomMove(
@@ -816,7 +844,7 @@ updateFullscreen <- function(NGLVieweR_proxy, fullscreen = TRUE){
 #'       duration = isolate(input$duration)
 #'     )
 #' })
-#' 
+#'
 #' observeEvent(input$reset, {
 #'   NGLVieweR_proxy("structure") %>%
 #'     updateZoomMove(
@@ -829,11 +857,24 @@ updateFullscreen <- function(NGLVieweR_proxy, fullscreen = TRUE){
 #' }
 #' shinyApp(ui, server)
 #' }
-#' @export
-updateZoomMove <- function(NGLVieweR_proxy, center, zoom, duration = 0, z_offSet = 0){
-  message <- list(id = NGLVieweR_proxy$id, center = center, zoom = zoom, duration = duration, z_offSet = z_offSet)
-  NGLVieweR_proxy$session$sendCustomMessage("NGLVieweR:updateZoomMove", message)
+#'@export
+updateZoomMove <- function(NGLVieweR_proxy, center, zoom, duration = 0, z_offSet = 0, structureIndex = NULL) {
+  
+  message <- list(
+    id = NGLVieweR_proxy$id,
+    center = center,
+    zoom = zoom,
+    duration = duration,
+    z_offSet = z_offSet
+  )
+  
+  if (!is.null(structureIndex)) {
+    message$structureIndex <- structureIndex
+  }
+  
 
+  NGLVieweR_proxy$session$sendCustomMessage("NGLVieweR:updateZoomMove", message)
+  
   return(NGLVieweR_proxy)
 }
 
